Ren2gev(object,
threshold = NULL,
w = 1,
distname.y = c("gpd", "GPD", "lomax", "maxlo"),
jacobian = (length(w) == 1L),
vcovRen = NULL)"Renouv".
In the first case, the names of the vector element must conform to
the distribution given in distname.y."gpd" but can be a "lomax" or a
"maxlo" distribution provided that the GEV parameters given
in object specify a TRUE, the jacobian matrix of the transformation
is computed. This is only possible at the time when w has
length 1.object has class "Renouv", then the covariance matrix
embedded in the object is used.w has length 1, a named vector of GEV parameters as
the one estimated by fgev. This vector has an
elements named "loc", "scale" and "shape".
When w has length > 1, a matrix with length(w)
rows, each representing a vector of GEV parameters as before.
The returned object has attributes named "threshold". and
"distname.y" to recall how it was built.gev2Ren function provides a reciprocal
transformation.fit1 <- Renouv(Garonne, distname.y = "maxlo")
Ren2gev(fit1)
fit2 <- Renouv(Garonne, distname.y = "gpd")
Ren2gev(fit2)Run the code above in your browser using DataLab