Learn R Programming

Renext (version 2.1-0)

RenouvNoEst: Define a 'renouvellement' model without estimation

Description

Build a 'renouvellement' model using parameters given by the user.

Usage

RenouvNoEst(threshold,
            estimate = NULL,
            distname.y = "exponential",
            fixed.par.y = NULL,
            trans.y = NULL,
            pct.conf = c(95, 70),
            rl.prob = NULL,
            prob.max = 1 - 1e-04,
            pred.period = NULL,
            cov = NULL,
            nb.OT = NULL,
            infer.method = NULL)

Arguments

threshold
The threshold.
estimate
Numeric named vector containing the estimates for the parameters. It must be compatible with the distribution chosen, and must contain in first position an element named "lambda" representing an estimated event rate in events
distname.y
Character giving the name of the distribution.
fixed.par.y
Numeric named vector containing values for vectors which are considered as fixed (and not estimated).
trans.y
Transformation as in Renouv. Used only when distname.y is equal to "exponential".
pct.conf
Vector of percents for confidence limits.
rl.prob
Probability used in the return level computations. These values are used for instance in return level plots produced with the plot.Renouv method. When NULL a default vector is u
prob.max
Maximal probability for which computations are done.
pred.period
Vector of periods for which predicted return levels will be computed.
cov
Covariance matrix for the provided estimated parameters. Must have rownames and colnames in accordance with those of estimate. This covariance matrix is used to build confidence limits on parameters and on return levels using the
nb.OT
Number of data over the threshold used for estimation. This will be used only when distname.y is equal to "exponential".
infer.method
Inference method. Will normally be the delta method.

Value

  • An object of class "Renouv" representing a 'renouvellement' model similar to those built with Renouv. This is mainly a list. Note however that some list elements found in Renouv objects built by Renouv can not be found here. For instance, the returned objects embeds no goodness-of-fit results since the object is created without making use of any data.

Details

This function is used for plotting or comparing models with known parameter estimates but with no data available. The parameters estimates should be accompanied with a covariance matrix assuming an approximatively normal joint distribution of these. This matrix is usually obtained by computing the numerical derivatives of the log-likelihood at the second order at the estimates. This covariance is used to compute approximate confidence limits for the return levels of the unknown true distribution that was estimated.

See Also

Renouv to estimate such models.

Examples

Run this code
##======================================================================
## Example from S. Coles' book, page 86 'rainfall data'
##======================================================================
estimate <- c(lambda = 152/48, scale = 7.44, shape = 0.184)          
cov <- matrix(c(4.9e-7,  0.0000,  0.0000,
                0.0000,  0.9180, -0.0655,
                0.0000, -0.0655,  0.0102),
              nrow = 3)
colnames(cov) <- rownames(cov) <- names(estimate)
renNE <- RenouvNoEst(threshold = 30, distname.y = "gpd",
                     pct.conf = c(95, 70),
                     estimate = estimate,
                     nb.OT = 152, cov = cov)
summary(renNE)
plot(renNE, main = "Daily rainfall data SW England", ylim = c(0, 400) )

Run the code above in your browser using DataLab