Learn R Programming

Renext (version 2.0-0)

summary.Renouv: Summary method for "Renouv" objects

Description

Summary method for "Renouv" objects representing 'Renouvellement' (POT) fitted models.

Usage

## S3 method for class 'Renouv':
summary(object,
        correlation = FALSE,
        symbolic.cor = FALSE,
        \dots)

## S3 method for class 'summary.Renouv': print(x, coef = TRUE, pred = TRUE, probT = FALSE, digits = max(3, getOption("digits") - 3), symbolic.cor = x$symbolic.cor, signif.stars = getOption("show.signif.stars"), ...)

## S3 method for class 'summary.Renouv': format(x, \dots)

Arguments

object
An object with class "Renouv".
x
An object of class "summary.Renouv", i.e. a result of a call to summary.Renouv.
correlation
Logical; if TRUE, the correlation matrix of the estimated parameters is returned and printed.
coef
Logical. If FALSE, the table of coefficients and t-ratios' will not be printed.
pred
Logical. If FALSE, the table of return periods/levels will not be printed.
probT
If FALSE, the $p$-values for the t-tests will not be printed nor displayed.
digits
the number of significant digits to use when printing.
symbolic.cor
logical. If TRUE, print the correlations in a symbolic form (see symnum) rather than as numbers.
signif.stars
logical. If TRUE, significance stars are printed for each coefficient.
...
Further arguments passed to or from other methods.

Value

  • The function summary.Rendata computes and returns a list of summary statistics concerning the object of class "Rendata" given in object. The returned list is an object with class "summary.Renouv". The function print.summary.Rendata does not returns anything.

Details

print.summary.Renouv tries to be smart about formatting the coefficients, standard errors, return levels, etc. format.summary.Renouv returns as a limited content as a character string. It does not embed coefficients values nor predictions.

See Also

The model fitting function Renouv (to build "Renouv" model objects), summary.

Examples

Run this code
library(Renext)
data(Brest)
fit <- Renouv(Brest)
summary(fit)

Run the code above in your browser using DataLab