Learn R Programming

Renext (version 2.1-10)

vcov.Renouv: Variance-covariance matrix of the estimates of a "Renouv" object.

Description

Variance-covariance matrix of the estimates of a "Renouv" object.

Usage

## S3 method for class 'Renouv':
vcov(object, ...)

Arguments

object
Object of class "Renouv".
...
Not used at the time.

Value

  • A variance-covariance matrix. The rows an columns correspond to the parameters of the Renouv object. The are the rate "lambda" for the Poisson process, and the parameters of the distribution for the exceedances, with names depending on the chosen distribution.

See Also

The vcov generic.