logLik.Renouv: Log-likelihood of a "Renouv" object.
Description
Log-likelihood, AIC, BIC and number of observations of an object of class "Renouv".Usage
## S3 method for class 'Renouv':
AIC(object, ..., k = 2)
## S3 method for class 'Renouv':
BIC(object, ...)
## S3 method for class 'Renouv':
logLik(object, ...)
## S3 method for class 'Renouv':
nobs(object, ...)
Arguments
object
Object of class "Renouv".
...
Other arguments passed to the default method.
Caution
Comparing log-likelihoods, AIC or BIC for different Renouv
objects makes sense only when these share the same data and the
same threshold.See Also
The AIC, nobs generic functions.