mom.mixexp2: Moment estimation for the mixture of two exponential distributions
Description
Compute the moment estimation for the tree parameters of the mixture of
two exponential distributions
Usage
mom.mixexp2(x)
Arguments
x
Sample. Vector containing values >0.
Value
A list with elements
estimateA vector with named elements "prob1", "rate1"
and "rate2". When the moment estimators are not valid
(negative or complex rates), a vector of three NA is
returned.
methodCharacter "moments"
Details
The three parameters (probability and the two rates) are computed from
the first three moments (theoretical and sample). It can be shown
that the inverse rates are obtained solving a quadratic
equation. However the roots can be negative or complex and the
estimates are not valid ones.
References
Paul R. Rider. The Method of Moments Applied to a Mixture of Two
Exponential Distributions. Ann. Math. Statist. Vol. 32, Number
1 (1961), 143-147.
See Also
See ini.mixexp2 for a more versatile initial
estimation.