pGreenwood1: Probability that the Greenwood's statistic is smaller than one
Description
Probability that the Greenwood's statistic is smaller than one.
Usage
pGreenwood1(n)
Arguments
n
Sample size.
Value
Probability that the Greenwood's statistic is smaller than one. For a
random sample of an exponential distribution with size $n$, this
is the probability that the coefficient of variation is less than one,
or the probability that the ML estimate of the GPD shape parameter
$\xi$ is negative.
Details
The probability was computed by using the approximation of the
quantile function of the Greenwood's statistic returned by
qStat. The result is found by interpolating the
distribution function for $x = 1$.